pub enum Error {
MissingFields {
required_fields: Vec<MissingField<'static>>,
},
ParseIntError(ParseIntError),
InconsistentSetting {
first_source: String,
first_setting: String,
second_source: String,
second_setting: String,
},
ParseFieldError {
field_name: &'static str,
field_type: &'static str,
error_condition: Box<dyn Error + Send + Sync>,
},
FileReadError(FileReadError),
}Expand description
All possible things that can go wrong when using partial_config.
Variants
MissingFields
Some of the required fields are missing
Fields
required_fields: Vec<MissingField<'static>>ParseIntError(ParseIntError)
A field that is supposed to be a number failed to be parsed from a string. Provided for convenience.
InconsistentSetting
A single setting was specified in two layers, and the two do not agree. This is useful in
cases where you want to debug a sticky setting that is strictly not supposed to be set,
but is. It is also used for different aliases in the EnvSourced infrastructure of this
crate.
ParseFieldError
The field failed to parse. This is a more generic, and therefore less useful version of the other errors. Consider creating your own error type if you plan to do anything other than print the error message after this point.
Fields
FileReadError(FileReadError)
The file failed to read.